import React, { useState, useEffect } from "react";
import {
  Form,
  Input,
  Button,
  Space,
  Table,
  Checkbox,
  InputNumber,
  Image,
} from "antd";
import Modal from "../../components/Modal";
import baseRequest from "../../utils/baseRequest";
import { useNavigate } from "react-router-dom";

//tab内容
const StreamerSpaceContent = () => {
  const navigate = useNavigate();
  const { TextArea } = Input;
  //展示的表头
  const [showColumns, setShowColumns] = useState([
    "baseInfo",
    "profile",
    "paymentSettings",
    "active",
    "ratio",
  ]);
  //动态的表头
  const dynamicColumns = showColumns.map((item) => {
    switch (item) {
      case "baseInfo":
        return {
          title: "基础信息",
          dataIndex: "baseInfo",
          key: "baseInfo",
          render: (data) => (
            <div>
              <Image src={data.avatar} width={50} />
              <p>
                ID：<span className="text-red-400">{data.id}</span>
              </p>
              <p>
                昵称：<span className="text-red-400">{data.name}</span>
              </p>
              <p>
                创建时间：<span className="text-red-400">{data.ct}</span>
              </p>
            </div>
          ),
        };
      case "profile":
        return {
          title: "空间介绍",
          dataIndex: "profile",
          key: "profile",
        };
      case "paymentSettings":
        return {
          title: "付费设置",
          dataIndex: "paymentSettings",
          key: "paymentSettings",
          render: (data) => (
            <div>
              <p>
                解锁空间价格：
                <span className="text-red-400">¥{data.admission_price}</span>
              </p>
              <p>
                铁粉价格：
                <span className="text-red-400">¥{data.ironfanship_price}</span>
              </p>
              <p>
                是否开启超粉功能：
                <span className="text-red-400">
                  {data.is_superfanship_enabled === 1 ? "是" : "否"}
                </span>
              </p>
              {data.is_superfanship_enabled === 1 && (
                <>
                  <p>
                    超粉价格：
                    <span className="text-red-400">
                      ¥{data.superfanship_price}
                    </span>
                  </p>
                  <p>
                    超粉有效期：
                    {data.superfanship_valid_period === 0 && (
                      <span className="text-red-400">永久</span>
                    )}
                    {data.superfanship_valid_period === 1 && (
                      <span className="text-red-400">月度</span>
                    )}
                    {data.superfanship_valid_period === 2 && (
                      <span className="text-red-400">季度</span>
                    )}
                    {data.superfanship_valid_period === 3 && (
                      <span className="text-red-400">半年</span>
                    )}
                    {data.superfanship_valid_period === 4 && (
                      <span className="text-red-400">年度</span>
                    )}
                  </p>
                  <p>
                    开通超粉是否送微信：
                    <span className="text-red-400">
                      {data.is_superfanship_give_wechat === 1 ? "是" : "否"}
                    </span>
                  </p>
                </>
              )}
            </div>
          ),
        };
      case "active":
        return {
          title: "活跃情况",
          dataIndex: "active",
          key: "active",
          render: (data) => (
            <div>
              <p>
                动态数量：
                <span className="text-red-400">{data.zone_moment_count}</span>
              </p>
              <p>
                图片数量：
                <span className="text-red-400">{data.image_count}</span>
              </p>
              <p>
                视频数量：
                <span className="text-red-400">{data.video_count}</span>
              </p>
              <p>
                最后发帖时间：
                <span className="text-red-400">{data.last_zone_moment_ct}</span>
              </p>
            </div>
          ),
        };
      case "ratio":
        return {
          title: "分成情况",
          dataIndex: "ratio",
          key: "ratio",
          render: (data) => (
            <div>
              {data.zone_third_partner?.third_partner_account?.mid && (
                <>
                  <p>
                    代运营ID：
                    <span className="text-red-400">
                      {data.zone_third_partner?.third_partner_account?.user_id}
                    </span>
                  </p>
                  <p>
                    代运营比例：
                    <span className="text-red-400">
                      {(data.zone_third_partner.sharing_ratio * 100).toFixed()}%
                    </span>
                  </p>
                </>
              )}
              <hr />
              {data.zone_collaborator_list.length !== 0 &&
                data.zone_collaborator_list?.map((item, index) => (
                  <div key={index}>
                    <p>
                      合伙人ID：
                      <span className="text-red-400">
                        {item?.collaborator_account?.user_id}
                      </span>
                    </p>
                    <p>
                      合伙人比例：
                      <span className="text-red-400">
                        {(item.sharing_ratio * 100).toFixed()}%
                      </span>
                    </p>
                    <br />
                  </div>
                ))}
            </div>
          ),
        };
      default:
        return {};
    }
  });
  dynamicColumns.push({
    title: "操作",
    dataIndex: "opeartion",
    key: "opeartion",
    render: (_, record) => (
      <div>
        <Space>
          <Space.Compact direction="vertical">
            <Button type="primary" onClick={() => handleModal(record)}>
              修改
            </Button>
            <Button
              onClick={() =>
                navigate(`/editSpacePost?user_id=${record.baseInfo.id}`)
              }
            >
              查看动态
            </Button>
          </Space.Compact>
        </Space>
      </div>
    ),
  });

  //表头可见性表单的checkbox选项
  const showColumnsOptions = [
    {
      label: "基础信息",
      value: "baseInfo",
    },
    {
      label: "空间介绍",
      value: "profile",
    },
    {
      label: "付费设置",
      value: "paymentSettings",
    },
    {
      label: "活跃情况",
      value: "active",
    },
    {
      label: "分成情况",
      value: "ratio",
    },
  ];
  //展示的数据
  const [showData, setShowData] = useState([]);
  //搜索空间
  const search = async (value) => {
    if (!value.id) {
      getAllSpace();
      return;
    }
    try {
      const base = baseRequest();
      const detailResponse = await fetch(`/op/zone/list_by_user_id`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          user_id: parseInt(value.id, 10),
          ...base,
        }),
      });
      const detailData = await detailResponse.json();
      if (detailData.ret === -1) {
        alert(detailData.msg);
        return;
      }
      const zone = detailData.data.list[0];
      setShowData([
        {
          key: zone.id,
          baseInfo: {
            id: zone.streamer_ext.user_id,
            name: zone.streamer_ext.name,
            avatar: zone.streamer_ext.avatar.images[0].urls[0],
            ct: new Date(zone.ct * 1000).toLocaleString(),
          },
          profile: zone.profile,
          paymentSettings: {
            admission_price: zone.admission_price / 100,
            ironfanship_price: zone.ironfanship_price / 100,
            is_superfanship_enabled: zone.is_superfanship_enabled,
            superfanship_price: zone.superfanship_price / 100,
            superfanship_valid_period: zone.superfanship_valid_period,
            is_superfanship_give_wechat: zone.is_superfanship_give_wechat,
          },
          active: {
            zone_moment_count: zone.zone_moment_count,
            image_count: zone.image_count,
            video_count: zone.video_count,
            last_zone_moment_ct: new Date(
              zone?.last_zone_moment_ct * 1000
            ).toLocaleString(),
          },
          ratio: {
            zone_third_partner: zone.zone_third_partner,
            zone_collaborator_list: zone.zone_collaborator_list,
          },
        },
      ]);
    } catch (error) {
      console.error(error);
    }
  };
  //表单提交失败
  const onFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };
  //展示所有已创建空间
  const getAllSpace = async () => {
    try {
      const base = baseRequest();
      const detailResponse = await fetch(`/op/zone/list`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          offset: 0,
          limit: 2000,
          ...base,
        }),
      });
      const detailData = await detailResponse.json();
      if (detailData.ret === -1) {
        alert(detailData.msg);
        return;
      }
      //匹配表格格式
      const structedData = detailData.data.list.map((item, index) => {
        return {
          key: item.id,
          baseInfo: {
            id: item.streamer_ext.user_id,
            name: item.streamer_ext.name,
            avatar: item.streamer_ext.avatar.images[0].urls[0],
            ct: new Date(item.ct * 1000).toLocaleString(),
          },
          profile: item.profile,
          paymentSettings: {
            admission_price: item.admission_price / 100,
            ironfanship_price: item.ironfanship_price / 100,
            is_superfanship_enabled: item.is_superfanship_enabled,
            superfanship_price: item.superfanship_price / 100,
            superfanship_valid_period: item.superfanship_valid_period,
            is_superfanship_give_wechat: item.is_superfanship_give_wechat,
          },
          active: {
            zone_moment_count: item.zone_moment_count,
            image_count: item.image_count,
            video_count: item.video_count,
            last_zone_moment_ct: new Date(
              item?.last_zone_moment_ct * 1000
            ).toLocaleString(),
          },
          ratio: {
            zone_third_partner: item.zone_third_partner,
            zone_collaborator_list: item.zone_collaborator_list,
          },
        };
      });
      setShowData(structedData);
    } catch (error) {
      console.error(error);
    }
  };
  useEffect(() => {
    getAllSpace();
  }, []);
  //modal是否展示
  const [isModalOpen, setIsModalOpen] = useState(false);
  //点击modal取消按钮
  const handleCancel = () => {
    setShowData([]);
    setDefaultValues({});
    setIsModalOpen(false);
  };
  //modal打开时的默认值
  const [defaultValues, setDefaultValues] = useState({});
  //点击修改按钮
  const handleModal = (record) => {
    setDefaultValues(record);
    setIsModalOpen(true);
  };
  //表单提交成功
  const onModalFormFinish = async (value) => {
    //上传表单操作...
    if (
      !value.admission_price?.toString() ||
      !value.ironfanship_price?.toString() ||
      !value.is_superfanship_enabled?.toString() ||
      !value.profile
    ) {
      alert("请完善表单信息");
      return;
    }
    if (
      parseInt(value.is_superfanship_enabled) === 1 &&
      (!value.superfanship_price?.toString() ||
        !value.superfanship_valid_period?.toString() ||
        !value.is_superfanship_give_wechat?.toString())
    ) {
      alert("请完善表单信息");
      return;
    }
    const _spacePrice = parseInt(value.admission_price * 100, 10);
    if (isNaN(_spacePrice) || _spacePrice < 0) {
      alert("请输入有效的解锁空间价格");
      return;
    }
    const _ironFanPrice = parseInt(value.ironfanship_price * 100, 10);
    if (isNaN(_ironFanPrice) || _ironFanPrice < 100 || _ironFanPrice > 388800) {
      alert("请输入有效的铁粉价格");
      return;
    }
    const _superFanPrice = parseInt(value.superfanship_price * 100, 10);
    if (
      parseInt(value.is_superfanship_enabled) === 1 &&
      (isNaN(_superFanPrice) || _superFanPrice < 100 || _superFanPrice > 388800)
    ) {
      alert("请输入有效的超粉价格");
      return;
    }
    if (
      parseInt(value.is_superfanship_enabled) === 1 &&
      _superFanPrice <= _ironFanPrice
    ) {
      alert("请输入大于铁粉价格的超粉价格");
      return;
    }
    try {
      const base = baseRequest();
      const detailResponse = await fetch(`/op/zone/update`, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({
          id: defaultValues.key,
          admission_price: parseInt(value.admission_price * 100, 10),
          ironfanship_price: parseInt(value.ironfanship_price * 100, 10),
          is_superfanship_enabled: parseInt(value.is_superfanship_enabled),
          superfanship_price: parseInt(value.superfanship_price * 100, 10),
          superfanship_valid_period: parseInt(
            value.superfanship_valid_period,
            10
          ),
          is_superfanship_give_wechat: parseInt(
            value.is_superfanship_give_wechat,
            10
          ),
          ...base,
        }),
      });
      const detailData = await detailResponse.json();
      if (detailData.ret === -1) {
        alert(detailData.msg);
        return;
      }
    } catch (error) {
      console.error(error);
    }
    //关闭模态
    setShowData([]);
    setDefaultValues({});
    setIsModalOpen(false);
  };
  //表单提交失败
  const onModalFormFinishFailed = (errorInfo) => {
    console.log("Failed:", errorInfo);
  };

  return (
    <div style={{ marginLeft: 20, marginRight: 20 }}>
      <div style={{ marginTop: 20, marginBottom: 10 }}>
        <p style={{ display: "inline" }}>数据可见性：</p>
        <Checkbox.Group
          options={showColumnsOptions}
          defaultValue={showColumns}
          onChange={(value) => setShowColumns(value)}
        />
      </div>
      <Form name="search" onFinish={search} onFinishFailed={onFinishFailed}>
        <Space style={{ marginBottom: 20 }}>
          <Form.Item label="ID" name="id" style={{ margin: 0 }}>
            <Input />
          </Form.Item>
          <Button type="primary" htmlType="submit">
            搜索
          </Button>
        </Space>
      </Form>
      <p>共{showData.length}条结果</p>
      <Table
        columns={dynamicColumns}
        dataSource={showData}
        pagination={{ pageSize: 20 }}
        scroll={{ y: window.innerHeight - 300 }}
      />
      {/* 模态框是否显示 */}
      {isModalOpen && (
        <Form
          name="change"
          onFinish={onModalFormFinish}
          onFinishFailed={onModalFormFinishFailed}
          autoComplete="off"
        >
          <Modal
            title="修改空间设置"
            cancel={handleCancel}
            content={
              <div
                className="flex flex-col overflow-y-scroll"
                style={{ height: (window.innerHeight * 2) / 3 }}
              >
                <div className="flex flex-row">
                  <Image
                    width={80}
                    height={80}
                    className="rounded-full"
                    src={defaultValues.baseInfo.avatar}
                  />
                  <div className="flex flex-col justify-between ml-2">
                    <p className="font-bold">ID：{defaultValues.baseInfo.id}</p>
                    <p className="font-bold">
                      昵称：{defaultValues.baseInfo.name}
                    </p>
                    <p className="font-bold">
                      创建时间：{defaultValues.baseInfo.ct}
                    </p>
                  </div>
                </div>
                <div
                  className="flex flex-row flex-wrap"
                  style={{ width: (window.innerWidth * 2) / 3 }}
                >
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="profile"
                    label="空间介绍"
                    initialValue={defaultValues.profile}
                    rules={[
                      {
                        required: true,
                        message: "请输入空间介绍",
                      },
                    ]}
                  >
                    <TextArea />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="admission_price"
                    label="解锁空间价格（元）"
                    initialValue={defaultValues.paymentSettings.admission_price}
                    rules={[
                      {
                        required: true,
                        message: "请输入解锁空间价格",
                      },
                    ]}
                  >
                    <InputNumber min={0} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="ironfanship_price"
                    label="铁粉价格（元）"
                    initialValue={
                      defaultValues.paymentSettings.ironfanship_price
                    }
                    rules={[
                      {
                        required: true,
                        message: "请输入铁粉价格",
                      },
                    ]}
                  >
                    <InputNumber min={0} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="is_superfanship_enabled"
                    label="是否开通超粉功能"
                    initialValue={
                      defaultValues.paymentSettings.is_superfanship_enabled
                    }
                    rules={[
                      {
                        required: true,
                        message: "请选择是否开通超粉功能",
                      },
                    ]}
                  >
                    <select
                      style={{
                        height: 32,
                        padding: "4px 11px",
                        border: "1px solid #d9d9d9",
                        borderRadius: 4,
                        outline: "none",
                      }}
                    >
                      <option value={1}>是</option>
                      <option value={0}>否</option>
                    </select>
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="superfanship_price"
                    label="超粉价格（元）"
                    initialValue={
                      defaultValues.paymentSettings.superfanship_price
                    }
                  >
                    <InputNumber min={0} />
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="superfanship_valid_period"
                    label="超粉有效期"
                    initialValue={
                      defaultValues.paymentSettings.superfanship_valid_period
                    }
                  >
                    <select
                      style={{
                        height: 32,
                        padding: "4px 11px",
                        border: "1px solid #d9d9d9",
                        borderRadius: 4,
                        outline: "none",
                      }}
                    >
                      <option value={0}>永久</option>
                      <option value={1}>月度</option>
                      <option value={2}>季度</option>
                      <option value={3}>半年</option>
                      <option value={4}>年度</option>
                    </select>
                  </Form.Item>
                  <Form.Item
                    className="basis-1/2 px-2"
                    name="is_superfanship_give_wechat"
                    label="开通超粉是否送微信"
                    initialValue={
                      defaultValues.paymentSettings.is_superfanship_give_wechat
                    }
                  >
                    <select
                      style={{
                        height: 32,
                        padding: "4px 11px",
                        border: "1px solid #d9d9d9",
                        borderRadius: 4,
                        outline: "none",
                      }}
                    >
                      <option value={1}>是</option>
                      <option value={0}>否</option>
                    </select>
                  </Form.Item>
                </div>
              </div>
            }
          />
        </Form>
      )}
    </div>
  );
};

export default function StreamerSpace() {
  return <StreamerSpaceContent />;
}
